import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
} from 'd3';
import { dropdownMenu } from './dropdownMenu';
import { scatterPlot } from './scatterPlot';

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

// State and handlers
let xColumn;
let yColumn;
let data;
const onXColumnClicked = value => {
  xColumn = value;
  render();
}
const onYColumnClicked = value => {
  yColumn = value;
  render()
}

const render = () => {
  
  select('#x-menu')
    .call(dropdownMenu, {
      selectedOption: xColumn,
      options: data.columns,
      onOptionClicked: onXColumnClicked,
  });
  
  select('#y-menu')
    .call(dropdownMenu, {
      selectedOption: yColumn,
      options: data.columns,
      onOptionClicked: onYColumnClicked,
  });
  
  svg.call(scatterPlot, {
    xValue: d => d[xColumn],
    xAxisLabel: xColumn,
    yValue: d => d[yColumn],
    yAxisLabel: yColumn,
    circleRadius: 10,
    margin: { top: 10, right: 40, bottom: 88, left: 130 },
    height,
    width,
    data,
  });
};

csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(loadedData => {
    data = loadedData;
    data.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;  
    });
  	
    yColumn = data.columns[0];
    xColumn = data.columns[4];
    render();
  });